| catch.r | R Documentation |
Catch-at-age standardized log residuals from a fitted stock assessment model.
catch.r
Data frame containing three columns:
Year | year |
Age | age |
Resid | standardized residual |
The values are from Table 8.6 in the ICES (2015) assessment of Icelandic saithe.
The standardized log residuals are based on observed and fitted catch at age:
log(Obs/Fit) / sigma
where sigma is the standard deviation of log(Obs/Fit).
ICES (2015) Report of the North-Western Working Group (NWWG). ICES CM 2015/ACOM:07, p. 246.
catch.d and catch.m are the observed catch-at-age
data.
bubbleplot-package gives an overview of the package.
# 1 Formula
bubbleplot(Catch~Age+Year, data=catch.d)
# Compare this plot with catch.m layout
print(catch.m)
bubbleplot(Catch~Age+Year, data=catch.d, rev=TRUE, las=TRUE)
# 2 Data frame
bubbleplot(catch.d)
# 3 Matrix or table
bubbleplot(catch.m)
catch.t <- xtabs(Catch~Year+Age, catch.d)
bubbleplot(catch.t)
# 4 Positive and negative values
bubbleplot(catch.r)
bubbleplot(Resid~Age+Year, catch.r, subset=Age %in% 4:9,
rev=TRUE, xlim=c(3.5,9.5), cex=1.3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.